Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS CloudHSM.

Actions, resources, and condition keys for AWS CloudHSM - Service Authorization Reference

# Actions, resources, and condition keys for AWS CloudHSM

AWS CloudHSM (service prefix: `cloudhsm` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS CloudHSM
- Resource types defined by AWS CloudHSM
- Condition keys for AWS CloudHSM

## Actions defined by AWS CloudHSM

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddTagsToResource | Adds or overwrites one or more tags for the specified AWS CloudHSM resource | Tagging |  |  |
CopyBackupToRegion | Grants permission to create a copy of a backup in the specified region | Write | backup* |  | cloudhsm:CopyBackupToRegion cloudhsm:TagResource cloudhsm:UntagResource
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateCluster | Grants permission to create a new AWS CloudHSM cluster | Write | backup |  | cloudhsm:TagResource ec2:AuthorizeSecurityGroupEgress ec2:AuthorizeSecurityGroupIngress ec2:CreateSecurityGroup ec2:DescribeSecurityGroups ec2:DescribeSubnets ec2:RevokeSecurityGroupEgress iam:CreateServiceLinkedRole
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateHapg | Creates a high-availability partition group | Write |  |  |
CreateHsm | Grants permission to create a new hardware security module (HSM) in the specified AWS CloudHSM cluster | Write | cluster* |  | ec2:AuthorizeSecurityGroupEgress ec2:AuthorizeSecurityGroupIngress ec2:CreateNetworkInterface ec2:CreateSecurityGroup ec2:DeleteNetworkInterface ec2:DescribeNetworkInterfaces ec2:DescribeSecurityGroups ec2:DescribeSubnets ec2:RevokeSecurityGroupEgress
CreateLunaClient | Creates an HSM client | Write |  |  |
DeleteBackup | Grants permission to delete the specified CloudHSM backup | Write | backup* |  |
DeleteCluster | Grants permission to delete the specified AWS CloudHSM cluster | Write | cluster* |  | ec2:DeleteNetworkInterface ec2:DeleteSecurityGroup
DeleteHapg | Deletes a high-availability partition group | Write |  |  |
DeleteHsm | Grants permission to delete the specified HSM | Write |  |  | ec2:DeleteNetworkInterface
DeleteLunaClient | Deletes a client | Write |  |  |
DescribeBackups | Grants permission to get information about backups of AWS CloudHSM clusters | Read |  |  |
DescribeClusters | Grants permission to get information about AWS CloudHSM clusters | Read |  |  |
DescribeHapg | Retrieves information about a high-availability partition group | Read |  |  |
DescribeHsm | Retrieves information about an HSM. You can identify the HSM by its ARN or its serial number | Read |  |  |
DescribeLunaClient | Retrieves information about an HSM client | Read |  |  |
GetConfig | Gets the configuration files necessary to connect to all high availability partition groups the client is associated with | Read |  |  |
InitializeCluster | Grants permission to claim an AWS CloudHSM cluster | Write | cluster* |  |
ListAvailableZones | Lists the Availability Zones that have available AWS CloudHSM capacity | List |  |  |
ListHapgs | Lists the high-availability partition groups for the account | List |  |  |
ListHsms | Retrieves the identifiers of all of the HSMs provisioned for the current customer | List |  |  |
ListLunaClients | Lists all of the clients | List |  |  |
ListTags | Grants permission to get a list of tags for the specified AWS CloudHSM cluster | Read | backup |  |
cluster |  |
ListTagsForResource | Returns a list of all tags for the specified AWS CloudHSM resource | Read |  |  |
ModifyBackupAttributes | Grants permission to modify attributes for an AWS CloudHSM backup | Write | backup* |  |
ModifyCluster | Grants permission to modify AWS CloudHSM cluster | Write | cluster* |  |
ModifyHapg | Modifies an existing high-availability partition group | Write |  |  |
ModifyHsm | Modifies an HSM | Write |  |  |
ModifyLunaClient | Modifies the certificate used by the client | Write |  |  |
RemoveTagsFromResource | Removes one or more tags from the specified AWS CloudHSM resource | Tagging |  |  |
RestoreBackup | Grants permission to restore the specified CloudHSM backup | Write | backup* |  |
TagResource | Grants permission to add or overwrite one or more tags for the specified AWS CloudHSM cluster | Tagging | backup |  |
cluster |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove the specified tag or tags from the specified AWS CloudHSM cluster | Tagging | backup |  |
cluster |  |
| aws:TagKeys |

## Resource types defined by AWS CloudHSM

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
backup | `arn:$ { Partition}:cloudhsm:$ { Region}:$ { Account}:backup/$ { CloudHsmBackupInstanceName}` | aws:ResourceTag/${TagKey}
cluster | `arn:$ { Partition}:cloudhsm:$ { Region}:$ { Account}:cluster/$ { CloudHsmClusterInstanceName}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS CloudHSM

AWS CloudHSM defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by tag key-value pairs attached to the resource | String
aws:TagKeys | Filters access by the presence of tag keys in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.